*** graph_forQJE.DO
*** 07/10/2016
***    News Shocks in Open Economies: Evidence from Giant Oil Discoveries
***            Arezki, Ramey and Sheng (2016)
**  Quarterly Journal of Economics, 2016
*** Description:
***          Graphs the empirical impulse responses 
***          Produce Figure VI-XI
*** Requires:
*** \baseline\irf_all.dta
*** \extension\irf_all_1.dta, irf_all_2.dta, and irf_all_3.dta
*** \twotype\irf_all_sizeonshore.dta and \twotype\irf_all_sizeoffshore.dta


version 12

clear all
drop _all
graph drop _all
set more off
set matsize 11000

** cd to the current folder


****************************************************************************************************************************************************************
* Part I: Baseline Empirical IRF: 
* Run after news_baseline_20150710.do
* Produce figure vi, vii, x
****************************************************************************************************************************************************************

cd baseline  // change to the baseline folder
use  irf_all.dta,clear

label var year "Year"
local lngdplcu_lab `" "GDP" "'
local ca_lab `" "Current Account/GDP" "'
local saving_lab `" "Saving/GDP" "'
local inv_lab `" "Investment/GDP" "'
local lnclcu_lab `" "Consumption" "'
local emprate_lab `" "Employment" "'

foreach var of varlist lngdplcu ca saving inv lnclcu emprate {
#delimit ;
twoway rarea `var'_min90 `var'_max90 year, color(gs14) || rarea `var'_min68 `var'_max68 year,  color(gs13) || connect `var' year, color(blue) 
 title(``var'_lab') legend(col(4) lab(1 "90CI") lab(2 "68CI") lab(3 "Est. IRF") ) name(empirf_`var',replace) nodraw
;
#delimit cr
graph save empirf_`var'.gph, replace
}


** Produce Figure VI: 

graph drop _all
grc1leg empirf_ca.gph empirf_saving.gph empirf_inv.gph , col(1) saving(figure_vi.gph, replace) name(figure_vi,replace)
graph display figure_vi, ysize(6) xsize(4) scale(0.8)
graph export figure_vi.eps, replace

** Produce Figure VII: 
grc1leg empirf_lngdplcu.gph empirf_lnclcu.gph empirf_emprate.gph, col(1) saving(figure_vii.gph, replace) name(figure_vii,replace)
graph display figure_vii, ysize(6) xsize(4) scale(0.8)
graph export figure_vii.eps, replace


** Figure X: Private versus Public Responses 

local invprivgdp_lab `" "Private Investment/GDP" "'
local invpubgdp_lab `" "Public Investment/GDP" "'
local lncp_r_lab `" "Private consumption" "'
local lncg_r_lab `" "Public consumption" "'
local govspgdp_lab `" "Government Spending/GDP" "'

foreach var of varlist invprivgdp  invpubgdp  lncp_r lncg_r {
#delimit ;
twoway rarea `var'_min90 `var'_max90 year, color(gs14) || rarea `var'_min68 `var'_max68 year,  color(gs13) || connect `var' year, color(blue) 
 title(``var'_lab') legend(col(4) lab(1 "90CI") lab(2 "68CI") lab(3 "Est. IRF") ) name(empirf_`var',replace) nodraw
;
#delimit cr
graph save empirf_`var'.gph, replace
}

* Only for govspgdp
#delimit ;
twoway rarea govspgdp_min90 govspgdp_max90 year, color(gs14) || rarea govspgdp_min68 govspgdp_max68 year,  color(gs13) || connect govspgdp year, color(blue) 
 fxsize(60) fysize(35) subtitle(`govspgdp_lab') legend(col(4) lab(1 "90CI") lab(2 "68CI") lab(3 "Est. IRF") ) name(empirf_govspgdp,replace) nodraw
;
#delimit cr
graph save empirf_govspgdp.gph, replace

* Combine private/public investment and consumption first
grc1leg  empirf_invprivgdp  empirf_invpubgdp  empirf_lncp_r empirf_lncg_r, col(2) saving(empirf_3.gph, replace) name(empirf_3,replace)

* Then combine with government spending/GDP
grc1leg empirf_3 empirf_govspgdp, col(1) saving(figure_x.gph, replace) name(figure_x,replace)

** Produce Figure X: 
graph display figure_x, ysize(5) xsize(4) scale(0.7)

graph export figure_x.eps, replace

*delete all temporary graphs
foreach var in empirf_ca.gph empirf_lngdplcu.gph  empirf_saving.gph empirf_lnclcu.gph empirf_inv.gph  empirf_emprate.gph  empirf_invprivgdp.gph  empirf_invpubgdp.gph   empirf_lncp_r.gph  empirf_lncg_r.gph  empirf_govspgdp.gph  empirf_3.gph {
erase `var'
}


** restore to the main directory
cd ..





****************************************************************************************************************************************************************
** Part II: IRF graphs of onshore discoveries and offshore discoveries
** Run after news_type_20160710.do
** Produce figure viii
****************************************************************************************************************************************************************

cd twotype // change to folder for two types of discoveriesw. 

use irf_all_sizeonshore.dta,clear

keep year lngdplcu ca saving inv lnclcu emprate

label var year "Year"

foreach var of varlist lngdplcu-emprate {
ren `var' `var'_a
label var `var' ""
}
sort year

save irf_all_on.dta, replace


use irf_all_sizeoffshore.dta,clear

keep year lngdplcu ca saving inv lnclcu emprate

foreach var of varlist lngdplcu-emprate {
ren `var' `var'_b
label var `var' ""
}
sort year

merge 1:1 year using irf_all_on.dta
drop _merge



graph drop _all

local lngdplcu_lab `" "GDP" "'
local ca_lab `" "Current Account/GDP" "'
local saving_lab `" "Saving/GDP" "'
local inv_lab `" "Investment/GDP" "'
local lnclcu_lab `" "Consumption" "'
local emprate_lab `" "Employment" "'


foreach var in ca saving inv lngdplcu  lnclcu emprate {
#delimit ;
twoway (connected `var'_a year, color(blue)) (connected `var'_b year, color(red) ms(d)) ,
 title(``var'_lab') legend(col(2) lab(1 "Onshore Discoveries") lab(2 "Offshore Discoveries")) name(`var'_onoff,replace) nodraw
;
#delimit cr
graph save `var'_onoff.gph, replace
}

** Produce figure_viii: Onshore discoveries v.s. Offshore discoveries

grc1leg ca_onoff.gph lngdplcu_onoff.gph saving_onoff.gph lnclcu_onoff.gph inv_onoff.gph emprate_onoff.gph, col(2) saving(figure_viii.gph, replace) name(figure_viii,replace)

graph display figure_viii, ysize(6) xsize(4) scale(0.8)
graph export figure_viii.eps,replace


foreach file in "ca" "saving" "inv" "lngdplcu" "lnclcu" "emprate"  {
erase `file'_onoff.gph
}

erase irf_all_on.dta

** restore to the main directory
cd ..




****************************************************************************************************************************************************************
** Part III: IRF graphs of high and low financial openness countries
** Run news_ext_20160710.do
** Produce figure ix
****************************************************************************************************************************************************************



** Using financial openness as a measure of borrowing constraint
** financial openness=(total asset+total liability)/gdp  


graph drop _all

cd extension


use irf_all_1.dta,clear

keep year lngdplcu ca saving inv lnclcu emprate

label var year "Year"

foreach var of varlist lngdplcu-emprate {
ren `var' `var'_a
label var `var' ""
}
sort year

save irf_a.dta, replace


use irf_all_2.dta,clear
keep year lngdplcu ca saving inv lnclcu emprate

foreach var of varlist lngdplcu-emprate {
ren `var' `var'_b
label var `var' ""
}
sort year

merge 1:1 year using irf_a.dta
drop _merge

local lngdplcu_lab `" "GDP" "'
local ca_lab `" "Current Account/GDP" "'
local saving_lab `" "Saving/GDP" "'
local inv_lab `" "Investment/GDP" "'
local lnclcu_lab `" "Consumption" "'
local emprate_lab `" "Employment" "'


foreach var in ca saving inv lngdplcu  lnclcu emprate {
#delimit ;
twoway (connected `var'_a year, color(blue)) (connected `var'_b year, color(red) ms(d)) ,
 title(``var'_lab') legend(col(4) lab(1 "High Fin. Openness.") lab(2 "Low Fin. Openness")) name(`var'_fo,replace) nodraw
;
#delimit cr
graph save `var'_fo.gph, replace
}

** Produce Figure IX: Financial openness: high vs low

grc1leg ca_fo.gph lngdplcu_fo.gph saving_fo.gph  lnclcu_fo.gph inv_fo.gph emprate_fo.gph, col(2) saving(figure_ix.gph, replace) name(figure_ix,replace)

graph display figure_ix, ysize(6) xsize(5) scale(0.8)

graph export figure_ix.eps,replace


** Erase all intermediate data files.
foreach file in "lngdplcu" "ca" "saving" "inv" "lnclcu" "emprate"{
erase `file'_fo.gph
}

erase irf_a.dta


cd ..


****************************************************************************************************************************************************************
** Part IV: Discovery event as oil news shock
** Run news_ext_20160710.do
** Produce Figure XI
****************************************************************************************************************************************************************

graph drop _all

cd extension  //change to the folder of extension

use  irf_all_3.dta,clear

label var year "Year"

local lngdplcu_lab `" "GDP" "'
local ca_lab `" "Current Account/GDP" "'
local saving_lab `" "Saving/GDP" "'
local inv_lab `" "Investment/GDP" "'
local lnclcu_lab `" "Consumption" "'
local emprate_lab `" "Employment" "'

foreach var of varlist lngdplcu ca saving inv lnclcu emprate {
#delimit ;
twoway rarea `var'_min90 `var'_max90 year, color(gs14) || rarea `var'_min68 `var'_max68 year,  color(gs13) || connect `var' year, color(blue) 
 title(``var'_lab') legend(col(4) lab(1 "90CI") lab(2 "68CI") lab(3 "Est. IRF") ) name(empirf_`var',replace) nodraw
;
#delimit cr
graph save empirf_`var'.gph, replace
}

** Produce Figure XI
grc1leg empirf_ca.gph empirf_lngdplcu.gph  empirf_saving.gph empirf_lnclcu.gph  empirf_inv.gph empirf_emprate.gph , col(2) saving(figure_xi.gph, replace) name(figure_xi,replace)

graph display figure_xi, ysize(6) xsize(4) scale(0.8)

graph export figure_xi.eps,replace


** Delete all temporary graphs
foreach var in empirf_ca.gph empirf_lngdplcu.gph  empirf_saving.gph empirf_lnclcu.gph empirf_inv.gph  empirf_emprate.gph  {
erase `var'
}



** restore to the main directory
cd ..

























